Constant Contact Python SDK
===========================

Constant Contact Python 2.x SDK for the v2 API.

## Installation

Installing the python sdk is simple.

```
$ pip install constantcontact
```

## Documentation

The Github pages for this repo are located [here](http://magellantoo.github.io/ctct-python-sdk/)  
And the API Documentation can be found [here](http://developer.constantcontact.com/docs/developer-guides/api-documentation-index.html)
